#[repr(C, packed(1))]pub struct ARAAudioModificationProperties {
pub structSize: ARASize,
pub name: ARAUtf8String,
pub persistentID: ARAPersistentID,
}Expand description
! Audio modification properties. ! Note that like all properties, a pointer to this struct is only valid for the duration of the ! call receiving the pointer - the data must be evaluated/copied inside the call, and the pointer ! must not be stored anywhere.
Fields
structSize: ARASize! @see_Versioned_Structs
name: ARAUtf8String! User-readable name of the audio modification as displayed in the host. ! The plug-in must copy the name, the pointer may be only valid for the duration of the call. ! It may be NULL if the host cannot provide a name for the audio modification. ! In that case, the host should not make up some name (e.g. derived from the audio source), but ! rather let the plug-in do this if desired - this way it can distinguish between a proper name ! visible somewhere in the host and a dummy name implicitly derived from other state.
persistentID: ARAPersistentID! ID used to re-connect model graph when archiving/unarchiving. ! This ID must be unique for all audio modifications within the document. ! The plug-in must copy the persistentID, the pointer may be only valid for the duration of the call.