#[repr(C, packed(1))]pub struct ARAColor {
pub r: f32,
pub g: f32,
pub b: f32,
}Expand description
! R/G/B color, values range from 0.0f to 1.0f. ! Does not include transparency because it must not depend on the background its drawn upon ! in order to be equally represented in both the host and plug-in UI - any transparency on ! either side must be converted depending on internal drawing before/after the ARA calls.
Fields
r: f32!< red
g: f32!< green
b: f32!< blue