#[repr(C, packed(1))]pub struct ARAContentBarSignature {
pub numerator: ARAInt32,
pub denominator: ARAInt32,
pub position: ARAQuarterPosition,
}Expand description
! Content reader event class: bar signatures provided by kARAContentTypeBarSignatures. ! The event position relates to ARAContentTempoEntry, a valid tempo map must be provided ! by any provider of ARAContentBarSignature. ! Each bar signature is valid until the following one, and the first bar signature is assumed to ! also be valid any time before it is actually defined. ! The location of the first bar signature is also considered to be the location of bar 1. ! Event sort order is by position. ! As with all content readers, a pointer to this struct retrieved via getContentReaderDataForEvent() ! is still owned by the callee and must remain valid until either getContentReaderDataForEvent() ! is called again or the reader is destroyed via destroyContentReader().
Fields
numerator: ARAInt32! Numerator of the bar signature.
denominator: ARAInt32! Denominator of the bar signature.
position: ARAQuarterPosition! Start time in quarter notes, see ARAContentTempoEntry.