ARAContentNote

Struct ARAContentNote 

#[repr(C, packed(1))]
pub struct ARAContentNote { pub frequency: f32, pub pitchNumber: ARAPitchNumber, pub volume: f32, pub startPosition: ARATimePosition, pub attackDuration: ARATimeDuration, pub noteDuration: ARATimeDuration, pub signalDuration: ARATimeDuration, }
! Content reader event class: notes provided by kARAContentTypeNotes. ! Event sort order is by startPosition. ! As with all content readers, a pointer to this struct retrieved via getContentReaderDataForEvent() ! is still owned by the callee and must remain valid until either getContentReaderDataForEvent() ! is called again or the reader is destroyed via destroyContentReader().

Fields

frequency: f32

! Average frequency in Hz, kARAInvalidFrequency if note has no defined pitch (percussive).

pitchNumber: ARAPitchNumber

! Index corresponding to MIDI note number (or kARAInvalidPitchNumber).

volume: f32

! Normalized level: 0.0f (weak) <= level <= 1.0f (strong). ! This value is scaled according to human perception (i.e. closer to a dB scale than to a linear one).

startPosition: ARATimePosition

! Time in seconds marking the beginning of the note (aka “note on” in MIDI), relative to the ! start of the song or the audio source/modification.

attackDuration: ARATimeDuration

! Time marking the musical/quantization anchor of the note, relative to the start of the note.

noteDuration: ARATimeDuration

! Time marking the release point of the note (aka “note off” in MIDI), relative to the start of the note.

signalDuration: ARATimeDuration

! Time marking the end of the entire sound of the note (end of release phase), relative to the start of the note.