#[repr(C, packed(1))]pub struct ARAContentTempoEntry {
pub timePosition: ARATimePosition,
pub quarterPosition: ARAQuarterPosition,
}Expand description
! Content reader event class: tempo map provided by kARAContentTypeTempoEntries. ! Event sort order is by timePosition. ! As with all content readers, a pointer to this struct retrieved via getContentReaderDataForEvent() ! is still owned by the callee and must remain valid until either getContentReaderDataForEvent() ! is called again or the reader is destroyed via destroyContentReader().
Fields
timePosition: ARATimePosition! Time in seconds relative to the start of the song or the audio source/modification.
quarterPosition: ARAQuarterPosition! Corresponding time in quarter notes.