ARAContentTuning

Struct ARAContentTuning 

#[repr(C, packed(1))]
pub struct ARAContentTuning { pub concertPitchFrequency: f32, pub root: ARACircleOfFifthsIndex, pub tunings: [f32; 12], pub name: ARAUtf8String, }
! Content reader event class: periodic 12-tone tuning table provided by kARAContentTypeStaticTuning. ! Defines the tuning of each pitch class in the octave-cyclic 12-tone pitch system. ! Allows to import (12-tone) Scala files. ! Stretched tunings are not supported by ARA at this point, but may be added in a future release ! as an additional tuning stretch curve applied on top of this average tuning. ! ARA defines a single overall tuning (i.e. there’s always only one event for this reader). ! As with all content readers, a pointer to this struct retrieved via getContentReaderDataForEvent() ! is still owned by the callee and must remain valid until either getContentReaderDataForEvent() ! is called again or the reader is destroyed via destroyContentReader().

Fields

concertPitchFrequency: f32

! Frequency of the concert pitch ‘A’ in hertz, defaulting to kARADefaultConcertPitchFrequency aka 440.0f.

root: ARACircleOfFifthsIndex

! Root key for the following per-key tunings.

tunings: [f32; 12]

! Tuning of each note pitch as an offset from the equal temperament tuning in cent. ! Each entry defaults to 0.0f. ! The first entry relates to the root, increasing chromatically up to the full octave. ! \verbatim ! Example: ! Arabian Rast: {0.0f, 0.0f, 0.0f, 0.0f, -50.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, -50.0f} ! \endverbatim

name: ARAUtf8String

! User-readable name of the tuning as displayed in the content provider. ! The tuning name may or may not include the root note, depending on context - for example, ! equal temperament does not care about the root note so it is always omitted, Werckmeister ! tunings typically imply a root note of C unless noted explicitly otherwise, etc. ! The name is provided only for display purposes, in case the receiver wants to display the ! tuning exactly as done in the sender instead of utilizing its built-in naming system for ! tunings based on the above properties. ! The receiver must copy the name, the pointer may be only valid as long as the containing ! ARAContentTuning struct. ! It may be NULL if the provider does not provide a name for the tuning in its UI.