#[repr(C, packed(1))]pub struct ARADocumentProperties {
pub structSize: ARASize,
pub name: ARAUtf8String,
}Expand description
! Document properties. ! Note that like all properties, a pointer to this struct is only valid for the duration of the ! call receiving the pointer - the data must be evaluated/copied inside the call, and the pointer ! must not be stored anywhere.
Fields
structSize: ARASize! @see_Versioned_Structs
name: ARAUtf8String! User-readable name of the document as displayed in the host. ! The plug-in must copy the name, the pointer may be only valid for the duration of the call. ! It may be NULL if the host cannot provide a name for the document. ! In that case, the host should not make up some dummy name just to satisfy the API, but ! rather let the plug-in do this if desired - this way it can distinguish between a proper ! name visible somewhere in the host and a dummy name implicitly derived from other state.