ARAPlugInExtensionInstance

Struct ARAPlugInExtensionInstance 

#[repr(C, packed(1))]
pub struct ARAPlugInExtensionInstance { pub structSize: ARASize, pub plugInExtensionRef: ARAPlugInExtensionRef, pub plugInExtensionInterface: *const ARAPlugInExtensionInterface, pub playbackRendererRef: ARAPlaybackRendererRef, pub playbackRendererInterface: *const ARAPlaybackRendererInterface, pub editorRendererRef: ARAEditorRendererRef, pub editorRendererInterface: *const ARAEditorRendererInterface, pub editorViewRef: ARAEditorViewRef, pub editorViewInterface: *const ARAEditorViewInterface, }
! The plug-in extension instance struct and all interfaces and refs therein must remain valid ! until the companion plug-in is destroyed by the host. ! Note that the companion plug-in destruction may happen before or after destroying the document ! controller it has been bound to, plug-ins must handle both possible destruction orders. ! Plug-ins must provide all interfaces that have been requested by the host through the role ! assignment, and suppress interfaces explicitly excluded by the roles - e.g. if the host did ! not assign kARAEditorRendererRole even it was known, editorRendererInterface will be NULL.

Fields

structSize: ARASize

! @see_Versioned_Structs_

plugInExtensionRef: ARAPlugInExtensionRefplugInExtensionInterface: *const ARAPlugInExtensionInterfaceplaybackRendererRef: ARAPlaybackRendererRefplaybackRendererInterface: *const ARAPlaybackRendererInterfaceeditorRendererRef: ARAEditorRendererRefeditorRendererInterface: *const ARAEditorRendererInterfaceeditorViewRef: ARAEditorViewRefeditorViewInterface: *const ARAEditorViewInterface