#[repr(C, packed(1))]pub struct ARAProcessingAlgorithmProperties {
pub structSize: ARASize,
pub persistentID: ARAPersistentID,
pub name: ARAUtf8String,
}Expand description
! Processing algorithm description returned by ARADocumentControllerInterface::getProcessingAlgorithmProperties() ! Provides a unique identifier and a user-readable name of the algorithm, as displayed in the plug-in. ! The pointers contained in this struct must remain valid until the document controller that has ! provided the struct is destroyed.
Fields
structSize: ARASize! @see_Versioned_Structs
persistentID: ARAPersistentID! ID for this particular processing algorithm.
name: ARAUtf8String! Name as displayed by the plug-in (may be localized).