ARAViewSelection

Struct ARAViewSelection 

#[repr(C, packed(1))]
pub struct ARAViewSelection { pub structSize: ARASize, pub playbackRegionRefsCount: ARASize, pub playbackRegionRefs: *const ARAPlaybackRegionRef, pub regionSequenceRefsCount: ARASize, pub regionSequenceRefs: *const ARARegionSequenceRef, pub timeRange: *const ARAContentTimeRange, }
! Host generated ARA view selection.

Fields

structSize: ARASize

! @see_Versioned_Structs

playbackRegionRefsCount: ARASize

! Length of #playbackRegionRefs.

playbackRegionRefs: *const ARAPlaybackRegionRef

! Variable-sized C array listing the explicitly selected playback regions. ! The list may be empty, in which case count should be 0 and the pointer NULL. ! If the plug-in requires a playback region selections in its view, it can derive an implicit ! playback region selection from the region sequence selection and the time range in that case.

regionSequenceRefsCount: ARASize

! Length of #regionSequenceRefs.

regionSequenceRefs: *const ARARegionSequenceRef

! Variable-sized C array listing the explicitly selected region sequences. ! The list may be empty, in which case count should be 0 and the pointer NULL. ! If the plug-in requires a region sequence selections in its view, it can derive an implicit ! region sequence selection from the playback region selection in that case.

timeRange: *const ARAContentTimeRange

! Pointer to the explicitly selected time range. ! This pointer can be NULL to indicate that selection command does not include an explicit ! time range selection. ! If the plug-in requires a time range selection in its view, it can derive an implicit ! time range selection from the playback region selection, or if that isn’t provided either ! it can evaluate the list of all playback regions of the selected region sequences.