pub type ARAArchiveReaderHostRef = *mut ARAArchiveReaderHostRefMarkupType;Expand description
! Reference to the host side representation of an archive reader (opaque to the plug-in).
pub type ARAArchiveReaderHostRef = *mut ARAArchiveReaderHostRefMarkupType;! Reference to the host side representation of an archive reader (opaque to the plug-in).