pub type ARAContentAccessControllerHostRef = *mut ARAContentAccessControllerHostRefMarkupType;Expand description
! Reference to the host side representation of a content access controller (opaque to the plug-in).
pub type ARAContentAccessControllerHostRef = *mut ARAContentAccessControllerHostRefMarkupType;! Reference to the host side representation of a content access controller (opaque to the plug-in).