pub type ARAContentReaderHostRef = *mut ARAContentReaderHostRefMarkupType;Expand description
! Reference to the host side representation of a content reader (opaque to the plug-in).
pub type ARAContentReaderHostRef = *mut ARAContentReaderHostRefMarkupType;! Reference to the host side representation of a content reader (opaque to the plug-in).