ARAContentUpdateFlags

Type Alias ARAContentUpdateFlags 

pub type ARAContentUpdateFlags = ARAInt32;
! Flags indicating the scope of a content update. ! If notifying the API partner about a content update, the caller can make guarantees about which ! abstractions of the signal are unaffected by the given change. ! The enum flags describing these abstractions are or’d together into a single ARAInt32 value. ! \br ! The C++ ARA Library encapsulates content updates in the ARA::ContentUpdateScopes class.