ARAKeySignatureIntervalUsage

Type Alias ARAKeySignatureIntervalUsage 

pub type ARAKeySignatureIntervalUsage = ARAByte;
! The ARAKeySignatureIntervalUsage defines whether a particular interval is used ! (kARAKeySignatureIntervalUsed) or not (kARAKeySignatureIntervalUnused). ! Future extensions of the API could further specify the usage of a given interval, similar to the ! chord intervals below. However since there are currently no clear-cut use cases for such a ! distinction, this is not yet specified.