pub type ARAModelUpdateControllerHostRef = *mut ARAModelUpdateControllerHostRefMarkupType;Expand description
! Reference to the host side representation of a model update controller (opaque to the plug-in).
pub type ARAModelUpdateControllerHostRef = *mut ARAModelUpdateControllerHostRefMarkupType;! Reference to the host side representation of a model update controller (opaque to the plug-in).