pub type ARAPlaybackControllerHostRef = *mut ARAPlaybackControllerHostRefMarkupType;Expand description
! Reference to the host side representation of a playback controller (opaque to the plug-in).
pub type ARAPlaybackControllerHostRef = *mut ARAPlaybackControllerHostRefMarkupType;! Reference to the host side representation of a playback controller (opaque to the plug-in).