pub type ARAPlaybackRegionHostRef = *mut ARAPlaybackRegionHostRefMarkupType;Expand description
! Reference to the host side representation of a playback region (opaque to the plug-in).
pub type ARAPlaybackRegionHostRef = *mut ARAPlaybackRegionHostRefMarkupType;! Reference to the host side representation of a playback region (opaque to the plug-in).