ARAPlaybackTransformationFlags

Type Alias ARAPlaybackTransformationFlags 

pub type ARAPlaybackTransformationFlags = ARAInt32;
! Playback region transformations. ! Plug-ins may or may not support all transformations that can be configured in a playback region. ! They express these capabilities at factory level, and the host must respect this. ! Also used in ARAFactory::supportedPlaybackTransformationFlags.