pub type ARAPlugInExtensionRef = *mut ARAPlugInExtensionRefMarkupType;Expand description
! @defgroup Plug-In_Extension_Interface Deprecated: Plug-In Extension Interface. ! This interface was used before ARA 2.0 defined dedicated plug-in roles. ! It is only to be implemented when ARA 1 backwards compatibility is desired. ! An ARA 1 call to set/removePlaybackRegion() in this interface is equivalent ! to calling both set/removePlaybackRegion() in ARAPlaybackRendererInterface ! and add/removePlaybackRegion() in ARAEditorRendererInterface. ! To some extend ARA 1 also uses this to for tasks now associated with ! ARAEditorViewInterface: opening the UI of an ARA 1 plug-in instance is ! interpreted as selection of the playback region set via this interface. ! @{