#[repr(C, packed(1))]pub struct ARAAudioSourceProperties {
pub structSize: ARASize,
pub name: ARAUtf8String,
pub persistentID: ARAPersistentID,
pub sampleCount: ARASampleCount,
pub sampleRate: ARASampleRate,
pub channelCount: ARAChannelCount,
pub merits64BitSamples: ARABool,
pub channelArrangementDataType: ARAChannelArrangementDataType,
pub channelArrangement: *const c_void,
}Expand description
! Audio source properties. ! Note that like all properties, a pointer to this struct is only valid for the duration of the ! call receiving the pointer - the data must be evaluated/copied inside the call, and the pointer ! must not be stored anywhere.
Fields
structSize: ARASize! @see_Versioned_Structs
name: ARAUtf8String! User-readable name of the audio source as displayed in the host. ! The plug-in must copy the name, the pointer may be only valid for the duration of the call. ! It may be NULL if the host cannot provide a name for the audio source. ! In that case, the host should not make up some dummy name just to satisfy the API, but ! rather let the plug-in do this if desired - this way it can distinguish between a proper ! name visible somewhere in the host and a dummy name implicitly derived from other state.
persistentID: ARAPersistentID! ID used to re-connect model graph when archiving/unarchiving. ! This ID must be unique for all audio sources within the document. ! The plug-in must copy the persistentID, the pointer may be only valid for the duration of the call.
sampleCount: ARASampleCount! Total number of samples per channel of the contained audio material. ! May only be changed while access to the audio source is disabled, ! see ARADocumentControllerInterface::enableAudioSourceSamplesAccess().
sampleRate: ARASampleRate! Sample rate of the contained audio material. ! May only be changed while access to the audio source is disabled, ! see ARADocumentControllerInterface::enableAudioSourceSamplesAccess(). ! Note that the sample rate of the audio source may not match the sample rate(s) used in the ! companion plug-in instances that render playback regions based on this audio source - ! plug-ins must apply sample rate conversion as needed. ! However, if the sample rate is changed, plug-ins are not required to translate their model ! to the new sample rate, and may instead restart with a fresh analysis, causing all user ! edits applied at the previous sample rate to be lost.
channelCount: ARAChannelCount! Count of discrete channels of the contained audio material. ! May only be changed while access to the audio source is disabled, ! see ARADocumentControllerInterface::enableAudioSourceSamplesAccess(). ! As with sample rate changes, plug-ins may discard all edits and start with a fresh analysis ! if the channel count is changed.
merits64BitSamples: ARABool! Flag to indicating that the data is available in a resolution that cannot be represented ! in 32 bit float samples without losing quality. ! Depending on its internal algorithms, the plug-in may or may not base its decision to ! read either 32 or 64 bit samples on this flag, ! see ARAAudioAccessControllerInterface::createAudioReaderForSource().
channelArrangementDataType: ARAChannelArrangementDataType! Type information of the data the opaque #channelArrangement actually points to. ! Host shall use the data type associated with the companion API that was used to create ! the respective document controller.
channelArrangement: *const c_void! Spacial arrangement information: defines which channel carries the signal from which direction. ! The data type that this pointer references is defined by #channelArrangementDataType, ! see ARAChannelArrangementDataType. ! \br ! If #channelCount not larger than 2 (i.e. mono or stereo), this information may omitted by ! setting #channelArrangementDataType to kARAChannelArrangementUndefined and #channelArrangement ! to NULL. The behavior is then the same as in hosts that do not support surround for ARA: ! for stereo, channel 0 is the left and channel 1 the right speaker. ! \br ! To determine which channel arrangements are supported by the plug-in, the host will use the ! companion API and read the valid render input formats.