#[repr(C, packed(1))]pub struct ARAContentKeySignature {
pub root: ARACircleOfFifthsIndex,
pub intervals: [ARAKeySignatureIntervalUsage; 12],
pub name: ARAUtf8String,
pub position: ARAQuarterPosition,
}Expand description
! Content reader event class: key signature provided by kARAContentTypeKeySignatures. ! Defines the usage of each pitch class in the octave-cyclic 12-tone pitch system. ! This content type describes the key signatures as would be annotated in a score, not the local ! scales (which may be using some out-of-key notes via additional per-note accidentals). ! The event position relates to ARAContentTempoEntry, a valid tempo map must be provided ! by any provider of ARAContentBarSignature. ! Each key signature is valid until the following one, the first key signature is assumed to also ! be valid any time before it is actually defined. ! Event sort order is by position. ! As with all content readers, a pointer to this struct retrieved via getContentReaderDataForEvent() ! is still owned by the callee and must remain valid until either getContentReaderDataForEvent() ! is called again or the reader is destroyed via destroyContentReader().
Fields
root: ARACircleOfFifthsIndex! Root key of the signature.
intervals: [ARAKeySignatureIntervalUsage; 12]! Scales intervals (aka scale mode) of the signature. ! The index of this arrays entry is the chromatic interval to the keys root pitch class. ! \verbatim ! Examples (Hex Values): ! major {FF, 00, FF, 00, FF, FF, 00, FF, 00, FF, 00, FF} ! natural minor {FF, 00, FF, FF, 00, FF, 00, FF, FF, 00, FF, 00} ! \endverbatim
name: ARAUtf8String! Optional user-readable name of the key signature as displayed in the content provider ! (including the root note name). ! Typically, the receiver has a built-in system to generate a suitable name for a key ! signature based on its internal abstractions. However, this internal model might cover all ! states that the ARA model can provide, or vice versa. If there is such a mismatch, the ! internal name generation algorithm will likely fail - in which case the receiver may fall ! back to the string provided here. ! Note that the utility library that ships with the ARA SDK contains C++ code that can create ! a proper name for the most common key signatures, otherwise falling back to this name. ! The receiver must copy the name, the pointer may be only valid as long as the containing ! ARAContentKeySignature struct. ! It may be NULL if the provider does not provide a name for the key signature in its UI. ! When encoding the string to send it across the ARA API, flat and sharp symbols must be ! represented with the Unicodes 0x266D “MUSIC FLAT SIGN” and 0x266F “MUSIC SHARP SIGN” ! respectively (as also required for ARAContentChord::name).
position: ARAQuarterPosition! Start time in quarter notes, see ARAContentTempoEntry.