#[repr(C, packed(1))]pub struct ARAContentTimeRange {
pub start: ARATimePosition,
pub duration: ARATimeDuration,
}Expand description
! Content reader optional creation parameter: a range in time to filter content events. ! As an optimization hint, a content reader can be asked to restrict its data to only those events ! that intersect with the given time range. Reader implementations should strive to respect this ! request, but focus on overall performance - the events actually returned may exceed the specified ! range by any amount, and calling code must evaluate the returned event positions/event durations. ! \br ! Note that when calls accept a pointer to a content time range, that pointer is only valid for ! the duration of the call - the data must be evaluated/copied inside the call, and the pointer ! must not be stored anywhere. ! Further, in most of these calls the pointer to a content range may be NULL, indicating that the ! entire content range of the object should be read.
Fields
start: ARATimePosition! Events at start time are considered part of the range.
duration: ARATimeDuration! Events at start time + duration are not considered part of the range.