#[repr(C, packed(1))]pub struct ARADocumentControllerHostInstance {
pub structSize: ARASize,
pub audioAccessControllerHostRef: ARAAudioAccessControllerHostRef,
pub audioAccessControllerInterface: *const ARAAudioAccessControllerInterface,
pub archivingControllerHostRef: ARAArchivingControllerHostRef,
pub archivingControllerInterface: *const ARAArchivingControllerInterface,
pub contentAccessControllerHostRef: ARAContentAccessControllerHostRef,
pub contentAccessControllerInterface: *const ARAContentAccessControllerInterface,
pub modelUpdateControllerHostRef: ARAModelUpdateControllerHostRef,
pub modelUpdateControllerInterface: *const ARAModelUpdateControllerInterface,
pub playbackControllerHostRef: ARAPlaybackControllerHostRef,
pub playbackControllerInterface: *const ARAPlaybackControllerInterface,
}Expand description
! The document controller host instance struct and all interfaces and refs therein must remain valid ! until all plug-in document controllers created with this struct have been destroyed by the host.
Fields
structSize: ARASize! @see_Versioned_Structs_
audioAccessControllerHostRef: ARAAudioAccessControllerHostRefaudioAccessControllerInterface: *const ARAAudioAccessControllerInterfacearchivingControllerHostRef: ARAArchivingControllerHostRefarchivingControllerInterface: *const ARAArchivingControllerInterfacecontentAccessControllerHostRef: ARAContentAccessControllerHostRefcontentAccessControllerInterface: *const ARAContentAccessControllerInterfacemodelUpdateControllerHostRef: ARAModelUpdateControllerHostRefmodelUpdateControllerInterface: *const ARAModelUpdateControllerInterfaceplaybackControllerHostRef: ARAPlaybackControllerHostRefplaybackControllerInterface: *const ARAPlaybackControllerInterfaceTrait Implementations
Sourceimpl Clone for ARADocumentControllerHostInstance
impl Clone for ARADocumentControllerHostInstance
Sourcefn clone(&self) -> ARADocumentControllerHostInstance
fn clone(&self) -> ARADocumentControllerHostInstance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ARADocumentControllerHostInstance