#[repr(C, packed(1))]pub struct ARAInterfaceConfiguration {
pub structSize: ARASize,
pub desiredApiGeneration: ARAAPIGeneration,
pub assertFunctionAddress: *mut ARAAssertFunction,
}Expand description
! API configuration. ! This configuration struct allows for setting the desired API version, the debug callback etc. ! Note that a pointer to this struct is only valid for the duration of the call to ! initializeARAWithConfiguration() - the data must be fully evaluated/copied inside the call.
Fields
structSize: ARASize! @see_Versioned_Structs
desiredApiGeneration: ARAAPIGeneration! Defines the API generation to use, must be within the range of supported generations.
assertFunctionAddress: *mut ARAAssertFunction! Pointer to the global assert function address. ! Be aware that this is a pointer to a function pointer, not the function pointer itself! ! This indirection is necessary so that plug-ins can inject their debug code if needed. ! The pointer must be the same for all instances that use the same API generation. ! It must be always provided by the host, but can point to NULL to suppress debugging in ! release versions. It must remain valid until uninitializeARA() is called.