#[repr(C, packed(1))]pub struct ARAPlaybackControllerInterface {
pub structSize: ARASize,
pub requestStartPlayback: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef)>,
pub requestStopPlayback: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef)>,
pub requestSetPlaybackPosition: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef, timePosition: ARATimePosition)>,
pub requestSetCycleRange: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef, startTime: ARATimePosition, duration: ARATimeDuration)>,
pub requestEnableCycle: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef, enable: ARABool)>,
}Expand description
! Host interface: playback controller. ! As with all host interfaces, the function pointers in this struct must remain valid until ! all document controllers on the plug-in side that use it have been destroyed.
Fields
structSize: ARASize! @see_Versioned_Structs
requestStartPlayback: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef)>! Message to the host to start playback of our document.
requestStopPlayback: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef)>! Message to the host to stop playback of our document.
requestSetPlaybackPosition: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef, timePosition: ARATimePosition)>! Message to the host to set the playback position of our document. ! Note that this may be called both when playing back or when stopped.
requestSetCycleRange: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef, startTime: ARATimePosition, duration: ARATimeDuration)>! Message to the host to set the playback cycle range of our document.
requestEnableCycle: Option<unsafe extern "C" fn(controllerHostRef: ARAPlaybackControllerHostRef, enable: ARABool)>! Message to the host to enable or disable the playback cycle of our document.