#[repr(C, packed(1))]pub struct ARAPlaybackRegionProperties {
pub structSize: ARASize,
pub transformationFlags: ARAPlaybackTransformationFlags,
pub startInModificationTime: ARATimePosition,
pub durationInModificationTime: ARATimeDuration,
pub startInPlaybackTime: ARATimePosition,
pub durationInPlaybackTime: ARATimeDuration,
pub musicalContextRef: ARAMusicalContextRef,
pub regionSequenceRef: ARARegionSequenceRef,
pub name: ARAUtf8String,
pub color: *const ARAColor,
}Expand description
! Playback region properties. ! Note that like all properties, a pointer to this struct is only valid for the duration of the ! call receiving the pointer - the data must be evaluated/copied inside the call, and the pointer ! must not be stored anywhere.
Fields
structSize: ARASize! @see_Versioned_Structs
transformationFlags: ARAPlaybackTransformationFlags! Configuration of possible transformations upon playback, i.e. time-stretching etc. ! The host may only enable flags that are listed in ARAFactory::supportedPlaybackTransformationFlags.
startInModificationTime: ARATimePosition! #startInModificationTime and #durationInModificationTime define the ! audible audio modification time range. This section of the modification’s audio data will ! be mapped to the song playback time range defined below as configured by the #transformationFlags, ! including optional time stretching. See @ref sec_ManipulatingTheTiming for more information.
durationInModificationTime: ARATimeDuration! See #startInModificationTime. \br ! Plug-ins must deal with #durationInModificationTime being 0.0.
startInPlaybackTime: ARATimePosition! #startInPlaybackTime and #durationInPlaybackTime define the relationship between the ! audible modification time range and the song playback time in seconds as communicated ! via the companion API. ! Musical context content (such as ::kARAContentTypeTempoEntries) is also expressed ! in song playback time.
durationInPlaybackTime: ARATimeDuration! See #startInPlaybackTime. \br ! Plug-ins must deal with #durationInPlaybackTime being 0.0.
musicalContextRef: ARAMusicalContextRef! Musical context in which the playback region will be edited and rendered. ! Note that when rendering the playback region via any plug-in instance, the time information ! provided for this plug-in through the companion API must match this musical context. ! \deprecated ! No longer used since adding region sequences in ARA 2.0, which already define the musical ! context for all their respective regions. If structSize indicates that a sequence is used ! (i.e. when using ARA 2.0 or higher), this field must be ignored by plug-ins. Hosts are ! free to additionally set a valid musical context if desired for ARA 1 backwards compatibility, ! or leave the field uninitialized otherwise.
regionSequenceRef: ARARegionSequenceRef! Region sequence with which the playback region is associated in the host. ! Required when using ARA 2_0_Draft or newer.
name: ARAUtf8String! User-readable name of the playback region as displayed in the host. ! The plug-in must copy the name, the pointer may be only valid for the duration of the call. ! It may be NULL if the host cannot provide a name for the audio modification. ! In that case, the host should not make up some name (e.g. derived from the audio source), but ! rather let the plug-in do this if desired - this way it can distinguish between a proper name ! visible somewhere in the host and a dummy name implicitly derived from other state.
color: *const ARAColor! Color associated with the playback region in the host. ! The plug-in must copy the color, the pointer may be only valid for the duration of the call. ! It may be NULL if the host cannot provide a color for the playback region. ! In that case, the host should not make up some color (e.g. derived from the track color), but ! rather let the plug-in do this if desired - this way it can distinguish between a proper color ! visible somewhere in the host and a dummy color implicitly derived from other state.