#[repr(C, packed(1))]pub struct ARARestoreObjectsFilter {
pub structSize: ARASize,
pub documentData: ARABool,
pub audioSourceIDsCount: ARASize,
pub audioSourceArchiveIDs: *const ARAPersistentID,
pub audioSourceCurrentIDs: *const ARAPersistentID,
pub audioModificationIDsCount: ARASize,
pub audioModificationArchiveIDs: *const ARAPersistentID,
pub audioModificationCurrentIDs: *const ARAPersistentID,
}Expand description
! Optional filter when restoring objects. ! \br ! Allows the host to specify a subset of the persistent objects in the archive to restore in ! ARADocumentControllerInterface::restoreObjectsFromArchive(). ! \br ! The given IDs refer to objects in the archive, but can optionally be mapped to those used in the ! current document. This may be necessary to resolve potential conflicts between persistent IDs ! from different documents when importing parts of one document into another (since persistent IDs ! are only required to be unique within a document, not across documents). ! \br ! The C++ ARA Library offers plug-in developers the ARA::PlugIn::RestoreObjectsFilter ! utility class to ease the implementation of partial persistency.
Fields
structSize: ARASize! @see_Versioned_Structs
documentData: ARABool! Flag to indicate whether the plug-in should include its private, opaque document state ! in the archive - see ARAStoreObjectsFilter::documentData for details.
audioSourceIDsCount: ARASize! Length of #audioSourceArchiveIDs and #audioSourceCurrentIDs (if provided).
audioSourceArchiveIDs: *const ARAPersistentID! Variable-sized C array listing the persistent IDs of the archived audio sources to restore. ! The list may be empty, in which case count should be 0 and the pointer NULL.
audioSourceCurrentIDs: *const ARAPersistentID! Optional variable-sized C array mapping each of the persistent IDs provided in audioSourceArchiveIDs ! to a potentially different persistent ID currently used for the audio sources to be restore ! in the current graph. ! If no mapping is desired, i.e. all audio source persistent IDs to restore match those in ! the current graph, the pointer should be NULL.
audioModificationIDsCount: ARASize! Length of #audioModificationArchiveIDs and #audioModificationCurrentIDs (if provided).
audioModificationArchiveIDs: *const ARAPersistentID! Variable-sized C array listing the persistent IDs of the archived audio modifications to restore. ! The list may be empty, in which case count should be 0 and the pointer NULL.
audioModificationCurrentIDs: *const ARAPersistentID! Optional variable-sized C array mapping each of the persistent IDs provided in audioModificationArchiveIDs ! to a potentially different persistent ID currently used for the audio modifications to be restore ! in the current graph. ! If no mapping is desired, i.e. all audio modification persistent IDs to restore match those in ! the current graph, the pointer should be NULL.